@@ -10,6 +10,7 @@ from instagrapi.mixins.comment import CommentMixin
 from instagrapi.mixins.direct import DirectMixin
 from instagrapi.mixins.hashtag import HashtagMixin
 from instagrapi.mixins.igtv import DownloadIGTVMixin, UploadIGTVMixin
+from instagrapi.mixins.clip import  DownloadClipMixin, UploadClipMixin
 from instagrapi.mixins.insights import InsightsMixin
 from instagrapi.mixins.location import LocationMixin
 from instagrapi.mixins.media import MediaMixin
@@ -52,6 +53,8 @@ class Client(
     CommentMixin,
     StoryMixin,
     PasswordMixin,
+    DownloadClipMixin,
+    UploadClipMixin,
 ):
     proxy = None
     logger = logging.getLogger("instagrapi")
