@@ -1,9 +1,24 @@
 from copy import deepcopy
 
-from .types import (Account, Collection, Comment, DirectMessage,
-                    DirectResponse, DirectThread, Hashtag, Location, Media,
-                    MediaOembed, Resource, Story, StoryLink, StoryMention,
-                    User, UserShort, Usertag)
+from .types import (
+    Account,
+    Collection,
+    Comment,
+    DirectMessage,
+    DirectResponse,
+    DirectThread,
+    Hashtag,
+    Location,
+    Media,
+    MediaOembed,
+    Resource,
+    Story,
+    StoryLink,
+    StoryMention,
+    User,
+    UserShort,
+    Usertag,
+)
 from .utils import InstagramIdCodec, json_value
 
 MEDIA_TYPES_GQL = {"GraphImage": 1, "GraphVideo": 2, "GraphSidecar": 8, "StoryVideo": 2}
@@ -92,8 +107,8 @@ def extract_media_gql(data):
             [
                 extract_usertag(usertag["node"])
                 for usertag in media.get("edge_media_to_tagged_user", {}).get(
-                "edges", []
-            )
+                    "edges", []
+                )
             ],
             key=lambda tag: tag.user.pk,
         ),
