@@ -4,9 +4,11 @@ from pathlib import Path
 from typing import List
 
 from instagrapi.exceptions import ClientNotFoundError, DirectThreadNotFound
-from instagrapi.extractors import (extract_direct_message,
-                                   extract_direct_response,
-                                   extract_direct_thread)
+from instagrapi.extractors import (
+    extract_direct_message,
+    extract_direct_response,
+    extract_direct_thread,
+)
 from instagrapi.types import DirectMessage, DirectResponse, DirectThread
 from instagrapi.utils import dumps
 
